Indsæt billeder

Indsæt billeder | TOC

Knappen "Indsæt billede" åbner et vindue, der ser ud som nedenfor.
Her indskriver man ganske enkelt adressen på det billede, man vil linke til samt en billedbeskrivelse. Denne beskrivelse bliver derefter vist som den alternative tekstbeskrivelse af billedet.
Feltbeskrivelser:

Image URL | Adressen på eller stien til billedet.
Image description | Alternativ tekstbeskrivelse af billedet.
Dimentions | Billedets bredde / højde.
Alignment | Billedets justering - brugbar når der skal sættes tekst på plads omkring et billede.
Border | Ramme bredde.
VSpace | Vertikal margen - brugbart når billedet skal placeres i en tekst.
HSpace | Horisontal margen - brugbart når billedet skal placeres i en tekst.

Tilbage til: Indholdsfortegnelse | Top